pub fn concat_elements_bytes<T: ByteArrayType>(
left: &GenericByteArray<T>,
right: &GenericByteArray<T>,
) -> Result<GenericByteArray<T>, ArrowError>Expand description
Returns the elementwise concatenation of a [GenericByteArray].
Errors
Returns an error if the arrays have different lengths, or if the concatenated data is too long for the offset type.