pub fn concat_elements_string_view_array(
left: &StringViewArray,
right: &StringViewArray,
) -> Result<StringViewArray, ArrowError>Expand description
Concatenates two StringViewArrays element-wise.
If either element is Null, the result element is also Null.
Errors
- Returns an error if the input arrays have different lengths.
- Returns an error if any concatenated value exceeds
u32::MAXin length. - Returns an error if concatenated strings do not result in a proper UTF-8 string