fn substring_by_char_impl<OffsetSize: OffsetSizeTrait, F: Fn(&str) -> (usize, usize)>(
array: &GenericStringArray<OffsetSize>,
max_element_len: Option<usize>,
bounds: F,
) -> GenericStringArray<OffsetSize>Expand description
Builds the output of substring_by_char, delegating to bounds to locate the
substring of each value.
max_element_len- an upper bound, in bytes, on the size of a single output element, used to avoid over-allocating the value buffer. None if unbounded.